HpkeAead

Struct HpkeAead 

pub struct HpkeAead(pub u16);
The Authenticated Encryption with Associated Data (Aead) type for HPKE operations. Listed by IANA, as specified in RFC 9180 Section 7.3

Protocol enumerations in rustls are represented with a struct, which contains the numeric value used on the wire (in this case, u16). Each known value has a named const item on this type – this can be used in a match arm or to access the numeric value.

If a known value does not exist for a value you need, you can simply create it locally:

pub const MyValue: HpkeAead = HpkeAead(123);

The Debug impl for this type also looks up and pretty-prints known named items. Unknown values are formatted in hexadecimal.

Tuple Fields

0: u16

Implementations

Source

impl HpkeAead

pub const AES_128_GCM: Self

pub const AES_256_GCM: Self

pub const CHACHA20_POLY_1305: Self

pub const EXPORT_ONLY: Self

pub fn to_array(self) -> [u8; 2]

Encode the value as a big-endian byte array.