pub struct HpkeKdf(pub u16);Expand description
The Key Derivation Function (Kdf) type for HPKE operations.
Listed by IANA, as specified in RFC 9180 Section 7.2
Protocol enumerations in rustls are represented with a struct, which contains the numeric value used on the wire (in this case, u16). Each known value has a named const item on this type – this can be used in a match arm or to access the numeric value.
If a known value does not exist for a value you need, you can simply create it locally:
pub const MyValue: HpkeKdf = HpkeKdf(123);The Debug impl for this type also looks up and pretty-prints
known named items. Unknown values are formatted in hexadecimal.
Tuple Fields
0: u16Implementations
Sourceimpl HpkeKdf
impl HpkeKdf