MacResult

Struct MacResult 

pub struct MacResult { /* private fields */ }
A MacResult wraps a Mac code and provides a safe Eq implementation that runs in fixed time.

Implementations

Source

impl MacResult

pub fn new(code: &[u8]) -> MacResult

Create a new MacResult.

pub fn new_from_owned(code: Vec<u8>) -> MacResult

Create a new MacResult taking ownership of the specified code value.

pub fn code<'s>(&'s self) -> &'s [u8]

Get the code value. Be very careful using this method, since incorrect use of the code value may permit timing attacks which defeat the security provided by the Mac function.