pub struct AesAad {
pub transfer_id: u8,
pub aad: Vec<u8>,
}Fields
transfer_id: u8aad: Vec<u8>Trait Implementations
Sourceimpl Archive for AesAad
impl Archive for AesAad
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedAesAad
type Archived = ArchivedAesAad
The archived representation of this type. Read more
Sourcetype Resolver = AesAadResolver
type Resolver = AesAadResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.