pub struct AesGcmTag {
pub transfer_id: u8,
}Fields
transfer_id: u8Trait Implementations
Sourceimpl Archive for AesGcmTagwhere
u8: Archive,
impl Archive for AesGcmTagwhere
u8: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedAesGcmTag
type Archived = ArchivedAesGcmTag
The archived representation of this type. Read more
Sourcetype Resolver = AesGcmTagResolver
type Resolver = AesGcmTagResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.