pub struct DiskEncryptUnsafe {
pub tweak: [u8; 16],
pub j: usize,
pub src: usize,
pub dst: usize,
pub len: usize,
pub direction: Direction,
}Fields
tweak: [u8; 16]j: usizesrc: usizedst: usizelen: usizedirection: DirectionTrait Implementations
Sourceimpl Archive for DiskEncryptUnsafe
impl Archive for DiskEncryptUnsafe
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedDiskEncryptUnsafe
type Archived = ArchivedDiskEncryptUnsafe
The archived representation of this type. Read more
Sourcetype Resolver = DiskEncryptUnsafeResolver
type Resolver = DiskEncryptUnsafeResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for DiskEncryptUnsafe
impl BlockingArchive for DiskEncryptUnsafe
Sourceimpl Debug for DiskEncryptUnsafe
impl Debug for DiskEncryptUnsafe
Sourceimpl<__D: Fallible + ?Sized> Deserialize<DiskEncryptUnsafe, __D> for Archived<DiskEncryptUnsafe>
impl<__D: Fallible + ?Sized> Deserialize<DiskEncryptUnsafe, __D> for Archived<DiskEncryptUnsafe>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<DiskEncryptUnsafe, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<DiskEncryptUnsafe, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for DiskEncryptUnsafe
impl MessageId for DiskEncryptUnsafe
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for DiskEncryptUnsafe
impl<__S: Fallible + ?Sized> Serialize<__S> for DiskEncryptUnsafe