pub struct Hmac {
pub algo: ShaAlgo,
pub key: Vec<u8>,
pub data: Vec<u8>,
}Fields
algo: ShaAlgokey: Vec<u8>data: Vec<u8>Trait Implementations
Sourceimpl Archive for Hmac
impl Archive for Hmac
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedHmac
type Archived = ArchivedHmac
The archived representation of this type. Read more
Sourcetype Resolver = HmacResolver
type Resolver = HmacResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.