pub struct ShaContextSnapshot {
pub algo: ShaAlgo,
pub hash_state: [u8; 64],
}Expand description
Snapshot of a server-side SHA context (returned by ShaGetContext).
Fields
algo: ShaAlgohash_state: [u8; 64]Trait Implementations
Sourceimpl Archive for ShaContextSnapshot
impl Archive for ShaContextSnapshot
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedShaContextSnapshot
type Archived = ArchivedShaContextSnapshot
The archived representation of this type. Read more
Sourcetype Resolver = ShaContextSnapshotResolver
type Resolver = ShaContextSnapshotResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for ShaContextSnapshot
impl Clone for ShaContextSnapshot
Sourcefn clone(&self) -> ShaContextSnapshot
fn clone(&self) -> ShaContextSnapshot
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ShaContextSnapshot
impl Debug for ShaContextSnapshot
Sourceimpl<__D: Fallible + ?Sized> Deserialize<ShaContextSnapshot, __D> for Archived<ShaContextSnapshot>
impl<__D: Fallible + ?Sized> Deserialize<ShaContextSnapshot, __D> for Archived<ShaContextSnapshot>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<ShaContextSnapshot, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<ShaContextSnapshot, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for ShaContextSnapshot
impl<__S: Fallible + ?Sized> Serialize<__S> for ShaContextSnapshot