pub struct ShamirRecover {
pub indexes: Vec<usize>,
pub shares: Vec<Vec<u8>>,
}Fields
indexes: Vec<usize>Trait Implementations
Sourceimpl Archive for ShamirRecover
impl Archive for ShamirRecover
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedShamirRecover
type Archived = ArchivedShamirRecover
The archived representation of this type. Read more
Sourcetype Resolver = ShamirRecoverResolver
type Resolver = ShamirRecoverResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for ShamirRecover
impl BlockingArchive for ShamirRecover
Sourceimpl Debug for ShamirRecover
impl Debug for ShamirRecover
Sourceimpl<__D: Fallible + ?Sized> Deserialize<ShamirRecover, __D> for Archived<ShamirRecover>
impl<__D: Fallible + ?Sized> Deserialize<ShamirRecover, __D> for Archived<ShamirRecover>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<ShamirRecover, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<ShamirRecover, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for ShamirRecover
impl MessageId for ShamirRecover
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for ShamirRecover
impl<__S: Fallible + ?Sized> Serialize<__S> for ShamirRecover