pub struct ShamirSplit {
pub secret: Vec<u8>,
pub num_shares: usize,
pub threshold: usize,
}Fields
secret: Vec<u8>threshold: usizeTrait Implementations
Sourceimpl Archive for ShamirSplit
impl Archive for ShamirSplit
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedShamirSplit
type Archived = ArchivedShamirSplit
The archived representation of this type. Read more
Sourcetype Resolver = ShamirSplitResolver
type Resolver = ShamirSplitResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for ShamirSplit
impl BlockingArchive for ShamirSplit
Sourceimpl Debug for ShamirSplit
impl Debug for ShamirSplit
Sourceimpl<__D: Fallible + ?Sized> Deserialize<ShamirSplit, __D> for Archived<ShamirSplit>
impl<__D: Fallible + ?Sized> Deserialize<ShamirSplit, __D> for Archived<ShamirSplit>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<ShamirSplit, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<ShamirSplit, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for ShamirSplit
impl MessageId for ShamirSplit
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for ShamirSplit
impl<__S: Fallible + ?Sized> Serialize<__S> for ShamirSplit