CipherSuite

Struct CipherSuite 

pub struct CipherSuite(pub u16);
The CipherSuite TLS protocol enum. Values in this enum are taken from the various RFCs covering TLS, and are listed by IANA.

Protocol enumerations in rustls are represented with a struct, which contains the numeric value used on the wire (in this case, u16). Each known value has a named const item on this type – this can be used in a match arm or to access the numeric value.

If a known value does not exist for a value you need, you can simply create it locally:

pub const MyValue: CipherSuite = CipherSuite(123);

The Debug impl for this type also looks up and pretty-prints known named items. Unknown values are formatted in hexadecimal.

Tuple Fields

0: u16

Implementations

Source

impl CipherSuite

pub const TLS_DHE_RSA_WITH_AES_128_GCM_SHA256: Self

The TLS_DHE_RSA_WITH_AES_128_GCM_SHA256 cipher suite. Recommended=Y. Defined in https://www.iana.org/go/rfc5288

pub const TLS_DHE_RSA_WITH_AES_256_GCM_SHA384: Self

The TLS_DHE_RSA_WITH_AES_256_GCM_SHA384 cipher suite. Recommended=Y. Defined in https://www.iana.org/go/rfc5288

pub const TLS_DHE_PSK_WITH_AES_128_GCM_SHA256: Self

The TLS_DHE_PSK_WITH_AES_128_GCM_SHA256 cipher suite. Recommended=Y. Defined in https://www.iana.org/go/rfc5487

pub const TLS_DHE_PSK_WITH_AES_256_GCM_SHA384: Self

The TLS_DHE_PSK_WITH_AES_256_GCM_SHA384 cipher suite. Recommended=Y. Defined in https://www.iana.org/go/rfc5487

pub const TLS13_AES_128_GCM_SHA256: Self

The TLS_AES_128_GCM_SHA256 cipher suite. Recommended=Y. Defined in https://www.iana.org/go/rfc8446

pub const TLS13_AES_256_GCM_SHA384: Self

The TLS_AES_256_GCM_SHA384 cipher suite. Recommended=Y. Defined in https://www.iana.org/go/rfc8446

pub const TLS13_CHACHA20_POLY1305_SHA256: Self

The TLS_CHACHA20_POLY1305_SHA256 cipher suite. Recommended=Y. Defined in https://www.iana.org/go/rfc8446

pub const TLS13_AES_128_CCM_SHA256: Self

The TLS_AES_128_CCM_SHA256 cipher suite. Recommended=Y. Defined in https://www.iana.org/go/rfc8446

pub const TLS_ECDHE_ECDSA_WITH_AES_128_GCM_SHA256: Self

The TLS_ECDHE_ECDSA_WITH_AES_128_GCM_SHA256 cipher suite. Recommended=Y. Defined in https://www.iana.org/go/rfc5289

pub const TLS_ECDHE_ECDSA_WITH_AES_256_GCM_SHA384: Self

The TLS_ECDHE_ECDSA_WITH_AES_256_GCM_SHA384 cipher suite. Recommended=Y. Defined in https://www.iana.org/go/rfc5289

pub const TLS_ECDHE_RSA_WITH_AES_128_GCM_SHA256: Self

The TLS_ECDHE_RSA_WITH_AES_128_GCM_SHA256 cipher suite. Recommended=Y. Defined in https://www.iana.org/go/rfc5289

pub const TLS_ECDHE_RSA_WITH_AES_256_GCM_SHA384: Self

The TLS_ECDHE_RSA_WITH_AES_256_GCM_SHA384 cipher suite. Recommended=Y. Defined in https://www.iana.org/go/rfc5289

pub const TLS_DHE_RSA_WITH_AES_128_CCM: Self

The TLS_DHE_RSA_WITH_AES_128_CCM cipher suite. Recommended=Y. Defined in https://www.iana.org/go/rfc6655

pub const TLS_DHE_RSA_WITH_AES_256_CCM: Self

The TLS_DHE_RSA_WITH_AES_256_CCM cipher suite. Recommended=Y. Defined in https://www.iana.org/go/rfc6655

pub const TLS_DHE_PSK_WITH_AES_128_CCM: Self

The TLS_DHE_PSK_WITH_AES_128_CCM cipher suite. Recommended=Y. Defined in https://www.iana.org/go/rfc6655

pub const TLS_DHE_PSK_WITH_AES_256_CCM: Self

The TLS_DHE_PSK_WITH_AES_256_CCM cipher suite. Recommended=Y. Defined in https://www.iana.org/go/rfc6655

pub const TLS_ECDHE_RSA_WITH_CHACHA20_POLY1305_SHA256: Self

The TLS_ECDHE_RSA_WITH_CHACHA20_POLY1305_SHA256 cipher suite. Recommended=Y. Defined in https://www.iana.org/go/rfc7905

pub const TLS_ECDHE_ECDSA_WITH_CHACHA20_POLY1305_SHA256: Self

The TLS_ECDHE_ECDSA_WITH_CHACHA20_POLY1305_SHA256 cipher suite. Recommended=Y. Defined in https://www.iana.org/go/rfc7905

pub const TLS_DHE_RSA_WITH_CHACHA20_POLY1305_SHA256: Self

The TLS_DHE_RSA_WITH_CHACHA20_POLY1305_SHA256 cipher suite. Recommended=Y. Defined in https://www.iana.org/go/rfc7905

pub const TLS_ECDHE_PSK_WITH_CHACHA20_POLY1305_SHA256: Self

The TLS_ECDHE_PSK_WITH_CHACHA20_POLY1305_SHA256 cipher suite. Recommended=Y. Defined in https://www.iana.org/go/rfc7905

pub const TLS_DHE_PSK_WITH_CHACHA20_POLY1305_SHA256: Self

The TLS_DHE_PSK_WITH_CHACHA20_POLY1305_SHA256 cipher suite. Recommended=Y. Defined in https://www.iana.org/go/rfc7905

pub const TLS_ECDHE_PSK_WITH_AES_128_GCM_SHA256: Self

The TLS_ECDHE_PSK_WITH_AES_128_GCM_SHA256 cipher suite. Recommended=Y. Defined in https://www.iana.org/go/rfc8442

pub const TLS_ECDHE_PSK_WITH_AES_256_GCM_SHA384: Self

The TLS_ECDHE_PSK_WITH_AES_256_GCM_SHA384 cipher suite. Recommended=Y. Defined in https://www.iana.org/go/rfc8442

pub const TLS_ECDHE_PSK_WITH_AES_128_CCM_SHA256: Self

The TLS_ECDHE_PSK_WITH_AES_128_CCM_SHA256 cipher suite. Recommended=Y. Defined in https://www.iana.org/go/rfc8442

pub const TLS_RSA_WITH_AES_128_CBC_SHA: Self

The TLS_RSA_WITH_AES_128_CBC_SHA cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc5246

pub const TLS_DHE_RSA_WITH_AES_128_CBC_SHA: Self

The TLS_DHE_RSA_WITH_AES_128_CBC_SHA cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc5246

pub const TLS_RSA_WITH_AES_256_CBC_SHA: Self

The TLS_RSA_WITH_AES_256_CBC_SHA cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc5246

pub const TLS_DHE_RSA_WITH_AES_256_CBC_SHA: Self

The TLS_DHE_RSA_WITH_AES_256_CBC_SHA cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc5246

pub const TLS_RSA_WITH_AES_128_CBC_SHA256: Self

The TLS_RSA_WITH_AES_128_CBC_SHA256 cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc5246

pub const TLS_RSA_WITH_AES_256_CBC_SHA256: Self

The TLS_RSA_WITH_AES_256_CBC_SHA256 cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc5246

pub const TLS_DHE_RSA_WITH_AES_128_CBC_SHA256: Self

The TLS_DHE_RSA_WITH_AES_128_CBC_SHA256 cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc5246

pub const TLS_DHE_RSA_WITH_AES_256_CBC_SHA256: Self

The TLS_DHE_RSA_WITH_AES_256_CBC_SHA256 cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc5246

pub const TLS_PSK_WITH_AES_128_CBC_SHA: Self

The TLS_PSK_WITH_AES_128_CBC_SHA cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc4279

pub const TLS_PSK_WITH_AES_256_CBC_SHA: Self

The TLS_PSK_WITH_AES_256_CBC_SHA cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc4279

pub const TLS_DHE_PSK_WITH_AES_128_CBC_SHA: Self

The TLS_DHE_PSK_WITH_AES_128_CBC_SHA cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc4279

pub const TLS_DHE_PSK_WITH_AES_256_CBC_SHA: Self

The TLS_DHE_PSK_WITH_AES_256_CBC_SHA cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc4279

pub const TLS_RSA_PSK_WITH_AES_128_CBC_SHA: Self

The TLS_RSA_PSK_WITH_AES_128_CBC_SHA cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc4279

pub const TLS_RSA_PSK_WITH_AES_256_CBC_SHA: Self

The TLS_RSA_PSK_WITH_AES_256_CBC_SHA cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc4279

pub const TLS_RSA_WITH_AES_128_GCM_SHA256: Self

The TLS_RSA_WITH_AES_128_GCM_SHA256 cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc5288

pub const TLS_RSA_WITH_AES_256_GCM_SHA384: Self

The TLS_RSA_WITH_AES_256_GCM_SHA384 cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc5288

pub const TLS_PSK_WITH_AES_128_GCM_SHA256: Self

The TLS_PSK_WITH_AES_128_GCM_SHA256 cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc5487

pub const TLS_PSK_WITH_AES_256_GCM_SHA384: Self

The TLS_PSK_WITH_AES_256_GCM_SHA384 cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc5487

pub const TLS_RSA_PSK_WITH_AES_128_GCM_SHA256: Self

The TLS_RSA_PSK_WITH_AES_128_GCM_SHA256 cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc5487

pub const TLS_RSA_PSK_WITH_AES_256_GCM_SHA384: Self

The TLS_RSA_PSK_WITH_AES_256_GCM_SHA384 cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc5487

pub const TLS_PSK_WITH_AES_128_CBC_SHA256: Self

The TLS_PSK_WITH_AES_128_CBC_SHA256 cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc5487

pub const TLS_PSK_WITH_AES_256_CBC_SHA384: Self

The TLS_PSK_WITH_AES_256_CBC_SHA384 cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc5487

pub const TLS_DHE_PSK_WITH_AES_128_CBC_SHA256: Self

The TLS_DHE_PSK_WITH_AES_128_CBC_SHA256 cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc5487

pub const TLS_DHE_PSK_WITH_AES_256_CBC_SHA384: Self

The TLS_DHE_PSK_WITH_AES_256_CBC_SHA384 cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc5487

pub const TLS_RSA_PSK_WITH_AES_128_CBC_SHA256: Self

The TLS_RSA_PSK_WITH_AES_128_CBC_SHA256 cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc5487

pub const TLS_RSA_PSK_WITH_AES_256_CBC_SHA384: Self

The TLS_RSA_PSK_WITH_AES_256_CBC_SHA384 cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc5487

pub const TLS13_SM4_GCM_SM3: Self

The TLS_SM4_GCM_SM3 cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc8998

pub const TLS13_SM4_CCM_SM3: Self

The TLS_SM4_CCM_SM3 cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc8998

pub const TLS_EMPTY_RENEGOTIATION_INFO_SCSV: Self

The TLS_EMPTY_RENEGOTIATION_INFO_SCSV cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc5746

pub const TLS13_AES_128_CCM_8_SHA256: Self

The TLS_AES_128_CCM_8_SHA256 cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc8446

pub const TLS_FALLBACK_SCSV: Self

The TLS_FALLBACK_SCSV cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc7507

pub const TLS_ECDHE_ECDSA_WITH_AES_128_CBC_SHA: Self

The TLS_ECDHE_ECDSA_WITH_AES_128_CBC_SHA cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc8422

pub const TLS_ECDHE_ECDSA_WITH_AES_256_CBC_SHA: Self

The TLS_ECDHE_ECDSA_WITH_AES_256_CBC_SHA cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc8422

pub const TLS_ECDHE_RSA_WITH_AES_128_CBC_SHA: Self

The TLS_ECDHE_RSA_WITH_AES_128_CBC_SHA cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc8422

pub const TLS_ECDHE_RSA_WITH_AES_256_CBC_SHA: Self

The TLS_ECDHE_RSA_WITH_AES_256_CBC_SHA cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc8422

pub const TLS_ECDHE_ECDSA_WITH_AES_128_CBC_SHA256: Self

The TLS_ECDHE_ECDSA_WITH_AES_128_CBC_SHA256 cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc5289

pub const TLS_ECDHE_ECDSA_WITH_AES_256_CBC_SHA384: Self

The TLS_ECDHE_ECDSA_WITH_AES_256_CBC_SHA384 cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc5289

pub const TLS_ECDHE_RSA_WITH_AES_128_CBC_SHA256: Self

The TLS_ECDHE_RSA_WITH_AES_128_CBC_SHA256 cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc5289

pub const TLS_ECDHE_RSA_WITH_AES_256_CBC_SHA384: Self

The TLS_ECDHE_RSA_WITH_AES_256_CBC_SHA384 cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc5289

pub const TLS_ECDHE_PSK_WITH_AES_128_CBC_SHA: Self

The TLS_ECDHE_PSK_WITH_AES_128_CBC_SHA cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc5489

pub const TLS_ECDHE_PSK_WITH_AES_256_CBC_SHA: Self

The TLS_ECDHE_PSK_WITH_AES_256_CBC_SHA cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc5489

pub const TLS_ECDHE_PSK_WITH_AES_128_CBC_SHA256: Self

The TLS_ECDHE_PSK_WITH_AES_128_CBC_SHA256 cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc5489

pub const TLS_ECDHE_PSK_WITH_AES_256_CBC_SHA384: Self

The TLS_ECDHE_PSK_WITH_AES_256_CBC_SHA384 cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc5489

pub const TLS_RSA_WITH_AES_128_CCM: Self

The TLS_RSA_WITH_AES_128_CCM cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc6655

pub const TLS_RSA_WITH_AES_256_CCM: Self

The TLS_RSA_WITH_AES_256_CCM cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc6655

pub const TLS_RSA_WITH_AES_128_CCM_8: Self

The TLS_RSA_WITH_AES_128_CCM_8 cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc6655

pub const TLS_RSA_WITH_AES_256_CCM_8: Self

The TLS_RSA_WITH_AES_256_CCM_8 cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc6655

pub const TLS_DHE_RSA_WITH_AES_128_CCM_8: Self

The TLS_DHE_RSA_WITH_AES_128_CCM_8 cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc6655

pub const TLS_DHE_RSA_WITH_AES_256_CCM_8: Self

The TLS_DHE_RSA_WITH_AES_256_CCM_8 cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc6655

pub const TLS_PSK_WITH_AES_128_CCM: Self

The TLS_PSK_WITH_AES_128_CCM cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc6655

pub const TLS_PSK_WITH_AES_256_CCM: Self

The TLS_PSK_WITH_AES_256_CCM cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc6655

pub const TLS_PSK_WITH_AES_128_CCM_8: Self

The TLS_PSK_WITH_AES_128_CCM_8 cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc6655

pub const TLS_PSK_WITH_AES_256_CCM_8: Self

The TLS_PSK_WITH_AES_256_CCM_8 cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc6655

pub const TLS_PSK_DHE_WITH_AES_128_CCM_8: Self

The TLS_PSK_DHE_WITH_AES_128_CCM_8 cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc6655

pub const TLS_PSK_DHE_WITH_AES_256_CCM_8: Self

The TLS_PSK_DHE_WITH_AES_256_CCM_8 cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc6655

pub const TLS_ECDHE_ECDSA_WITH_AES_128_CCM: Self

The TLS_ECDHE_ECDSA_WITH_AES_128_CCM cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc7251

pub const TLS_ECDHE_ECDSA_WITH_AES_256_CCM: Self

The TLS_ECDHE_ECDSA_WITH_AES_256_CCM cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc7251

pub const TLS_ECDHE_ECDSA_WITH_AES_128_CCM_8: Self

The TLS_ECDHE_ECDSA_WITH_AES_128_CCM_8 cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc7251

pub const TLS_ECDHE_ECDSA_WITH_AES_256_CCM_8: Self

The TLS_ECDHE_ECDSA_WITH_AES_256_CCM_8 cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc7251

pub const TLS_SHA256_SHA256: Self

The TLS_SHA256_SHA256 cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc9150

pub const TLS_SHA384_SHA384: Self

The TLS_SHA384_SHA384 cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc9150

pub const TLS_PSK_WITH_CHACHA20_POLY1305_SHA256: Self

The TLS_PSK_WITH_CHACHA20_POLY1305_SHA256 cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc7905

pub const TLS_RSA_PSK_WITH_CHACHA20_POLY1305_SHA256: Self

The TLS_RSA_PSK_WITH_CHACHA20_POLY1305_SHA256 cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc7905

pub const TLS_ECDHE_PSK_WITH_AES_128_CCM_8_SHA256: Self

The TLS_ECDHE_PSK_WITH_AES_128_CCM_8_SHA256 cipher suite. Recommended=N. Defined in https://www.iana.org/go/rfc8442

pub fn to_array(self) -> [u8; 2]

Encode the value as a big-endian byte array.