HashAlgorithm

Struct HashAlgorithm 

pub struct HashAlgorithm(pub u8);
The HashAlgorithm TLS protocol enum. Values in this enum are taken from the various RFCs covering TLS, and are listed by IANA.

Protocol enumerations in rustls are represented with a struct, which contains the numeric value used on the wire (in this case, u8). Each known value has a named const item on this type – this can be used in a match arm or to access the numeric value.

If a known value does not exist for a value you need, you can simply create it locally:

pub const MyValue: HashAlgorithm = HashAlgorithm(123);

The Debug impl for this type also looks up and pretty-prints known named items. Unknown values are formatted in hexadecimal.

Tuple Fields

0: u8

Implementations

Source

impl HashAlgorithm

pub const NONE: Self

pub const MD5: Self

pub const SHA1: Self

pub const SHA224: Self

pub const SHA256: Self

pub const SHA384: Self

pub const SHA512: Self

pub fn to_array(self) -> [u8; 1]

Encode the value as a big-endian byte array.