SignatureAlgorithm

Struct SignatureAlgorithm 

pub struct SignatureAlgorithm(pub u8);
The SignatureAlgorithm TLS protocol enum. Values in this enum are taken from the various RFCs covering TLS, and are listed by IANA.

Protocol enumerations in rustls are represented with a struct, which contains the numeric value used on the wire (in this case, u8). Each known value has a named const item on this type – this can be used in a match arm or to access the numeric value.

If a known value does not exist for a value you need, you can simply create it locally:

pub const MyValue: SignatureAlgorithm = SignatureAlgorithm(123);

The Debug impl for this type also looks up and pretty-prints known named items. Unknown values are formatted in hexadecimal.

Tuple Fields

0: u8

Implementations

Source

impl SignatureAlgorithm

pub const Anonymous: Self

pub const RSA: Self

pub const DSA: Self

pub const ECDSA: Self

pub const ED25519: Self

pub const ED448: Self

pub fn to_array(self) -> [u8; 1]

Encode the value as a big-endian byte array.