WebPkiSupportedAlgorithms

Struct WebPkiSupportedAlgorithms 

pub struct WebPkiSupportedAlgorithms { /* private fields */ }
Describes which webpki signature verification algorithms are supported and how they map to TLS SignatureSchemes.

Create one with WebPkiSupportedAlgorithms::new, which can be done in const-context.

Implementations

Source

impl WebPkiSupportedAlgorithms

pub const fn new( all: &'static [&'static dyn SignatureVerificationAlgorithm], mapping: &'static [(SignatureScheme, &'static [&'static dyn SignatureVerificationAlgorithm])], ) -> Result<Self, ApiMisuse>

Creating a WebPkiSupportedAlgorithms and checking its consistency.

This is intended to only be called in const context, so the panics are compile-time.

pub fn supported_schemes(&self) -> Vec<SignatureScheme>

Return all the scheme items in mapping, maintaining order.

pub fn fips(&self) -> FipsStatus

Return the FIPS validation status of this implementation.

pub fn mapping( &self, ) -> &'static [(SignatureScheme, &'static [&'static dyn SignatureVerificationAlgorithm])]

Accessor for the mapping field.