Crate af_keys

Light-weight, read-only version of Sui’s file-based keystore.

This crate uses eyre and is meant for applications, not libraries.

The medium-term plan is to deprecate most of this in favor of sui_crypto.

Re-exports

Modules

Functions