pub struct SignatureScheme(pub u16);Expand description
The SignatureScheme TLS protocol enum. Values in this enum are taken
from the various RFCs covering TLS, and are listed by IANA.
Protocol enumerations in rustls are represented with a struct, which contains the numeric value used on the wire (in this case, u16). Each known value has a named const item on this type – this can be used in a match arm or to access the numeric value.
If a known value does not exist for a value you need, you can simply create it locally:
pub const MyValue: SignatureScheme = SignatureScheme(123);The Debug impl for this type also looks up and pretty-prints
known named items. Unknown values are formatted in hexadecimal.
Tuple Fields
0: u16Implementations
Sourceimpl SignatureScheme
impl SignatureScheme
pub const RSA_PKCS1_SHA1: Self
pub const ECDSA_SHA1_Legacy: Self
pub const RSA_PKCS1_SHA256: Self
pub const ECDSA_NISTP256_SHA256: Self
pub const RSA_PKCS1_SHA384: Self
pub const ECDSA_NISTP384_SHA384: Self
pub const RSA_PKCS1_SHA512: Self
pub const ECDSA_NISTP521_SHA512: Self
pub const RSA_PSS_SHA256: Self
pub const RSA_PSS_SHA384: Self
pub const RSA_PSS_SHA512: Self
pub const ED25519: Self
pub const ED448: Self
pub const ML_DSA_44: Self
pub const ML_DSA_65: Self
pub const ML_DSA_87: Self